#set( $symbol_pound = '#' )
#set( $symbol_dollar = '$' )
#set( $symbol_escape = '\' )
/*
 * Copyright (C) 2005-2012 Alfresco Software Limited.
 *
 * This file is part of Alfresco
 *
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 */
package ${package}.data;

import java.io.Serializable;

import org.springframework.data.mongodb.core.MongoTemplate;
import org.springframework.data.mongodb.core.query.Criteria;
import org.springframework.data.mongodb.core.query.Query;
import org.springframework.data.mongodb.core.query.Update;

import com.mongodb.BasicDBObjectBuilder;
import com.mongodb.DBObject;
import com.mongodb.WriteResult;

/**
 * Sample POJO for demonstration.  This file should be deleted.
 * 
 * @author Derek Hulley
 * @since 1.0
 */
public class ProcessData implements Serializable
{
    private static final long serialVersionUID = -4741893659787720414L;
    
    public static final String FIELD_ID = "id";
    public static final String FIELD_PROCESS_NAME = "processName";
    public static final String FIELD_DONE = "done";

    private String id;
    private String processName;
    private boolean done;

    /**
     * Ensure that the MongoDB collection has the required indexes associated with
     * this user bean.
     * 
     * @param mongo                 connection to MongoDB
     * @param collectionName        name of DB collection containing data
     */
    public static void checkIndexes(MongoTemplate mongo, String collectionName)
    {
        DBObject idxProcessName = BasicDBObjectBuilder
                .start(FIELD_PROCESS_NAME, 1)
                .get();
        mongo.getDb().getCollection(collectionName).ensureIndex(idxProcessName, "idx_procname", true);
        DBObject idxDone = BasicDBObjectBuilder
                .start(FIELD_DONE, 1)
                .get();
        mongo.getDb().getCollection(collectionName).ensureIndex(idxDone, "idx_done", false);
    }
    
    /**
     * Utility method to find a user by process name
     * 
     * @param mongo                 connection to MongoDB
     * @param collectionName        name of DB collection containing data
     * @param processName           the name of the process to find
     * @return                      Returns the data or <tt>null</tt> if not found
     */
    public static ProcessData findProcessByName(MongoTemplate mongo, String collectionName, String processName)
    {
        Criteria criteriaProcNameIs = Criteria.where(ProcessData.FIELD_PROCESS_NAME).is(processName);
        Query queryProcByProcName = new Query(criteriaProcNameIs);
        ProcessData data = mongo.findOne(queryProcByProcName, ProcessData.class, collectionName);
        // Done
        return data;
    }
    
    /**
     * Utility method to find a user by process name
     * 
     * @param mongo                 connection to MongoDB
     * @param collectionName        name of DB collection containing data
     * @param processName           the name of the process to update
     * @return                      the number of rows updated
     */
    public static int markAsDone(MongoTemplate mongo, String collectionName, String processName)
    {
        Criteria criteriaProcNameIs = Criteria.where(ProcessData.FIELD_PROCESS_NAME).is(processName);
        Query queryProcByProcName = new Query(criteriaProcNameIs);
        Update update = Update.update(FIELD_DONE, Boolean.TRUE);
        WriteResult result = mongo.updateFirst(queryProcByProcName, update, collectionName);
        // Done
        return result.getN();
    }
    
    public String getId()
    {
        return id;
    }
    public void setId(String id)
    {
        this.id = id;
    }

    public String getProcessName()
    {
        return processName;
    }

    public void setProcessName(String processName)
    {
        this.processName = processName;
    }

    public boolean isDone()
    {
        return done;
    }

    public void setDone(boolean done)
    {
        this.done = done;
    }
}
